@@ -500,6 +500,44 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     }
 
     subset_seq <- seq(lower_subset, upper_subset)
+
+
+
+
+
+
+    if (any(!(subset_seq %in% row.names(response)))){
+
+      stop(paste0("Undefined columns selected. Subset years don't exist",
+                  " in the response data frame. Change the subset_years argument"))
+    }
+
+    if (any(!(subset_seq %in% row.names(env_data_primary)))){
+
+      stop(paste0("Undefined columns selected. Subset years don't exist",
+                  " in the env_data_primary data frame. Change the subset_years argument"))
+    }
+
+    if (any(!(subset_seq %in% row.names(env_data_control)))){
+
+      stop(paste0("Undefined columns selected. Subset years don't exist",
+                  " in the env_data_control data frame. Change the subset_years argument"))
+    }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
     response <- subset(response, row.names(response) %in% subset_seq)
     env_data_primary <- subset(env_data_primary, row.names(env_data_primary) %in% subset_seq)
     env_data_control <- subset(env_data_control, row.names(env_data_control) %in% subset_seq)
@@ -624,8 +662,37 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
             temporal_upper <- NA
 
           } else {
-            temporal_lower <- ci_int$norm[2]
-            temporal_upper <- ci_int$norm[3]
+
+            if (boot_ci_type == "norm"){
+
+              temporal_lower <- ci_int$norm[2]
+              temporal_upper <- ci_int$norm[3]
+
+            } else if (boot_ci_type == "perc"){
+
+              temporal_lower <- ci_int$perc[4]
+              temporal_upper <- ci_int$perc[5]
+
+            } else if (boot_ci_type == "stud") {
+
+              temporal_lower <- ci_int$student[4]
+              temporal_upper <- ci_int$student[5]
+
+            } else if (boot_ci_type == "basic") {
+
+              temporal_lower <- ci_int$basic[4]
+              temporal_upper <- ci_int$basic[5]
+
+            } else if (boot_ci_type == "bca") {
+
+              temporal_lower <- ci_int$bca[4]
+              temporal_upper <- ci_int$bca[5]
+
+            } else {
+
+              stop("boot_ci_type should be 'norm', 'perc', 'stud', 'basic' or 'bca'")
+
+            }
           }
 
           if (reference_window == 'start'){
@@ -812,8 +879,36 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
           temporal_upper <- NA
 
         } else {
-          temporal_lower <- ci_int$norm[2]
-          temporal_upper <- ci_int$norm[3]
+          if (boot_ci_type == "norm"){
+
+            temporal_lower <- ci_int$norm[2]
+            temporal_upper <- ci_int$norm[3]
+
+          } else if (boot_ci_type == "perc"){
+
+            temporal_lower <- ci_int$perc[4]
+            temporal_upper <- ci_int$perc[5]
+
+          } else if (boot_ci_type == "stud") {
+
+            temporal_lower <- ci_int$student[4]
+            temporal_upper <- ci_int$student[5]
+
+          } else if (boot_ci_type == "basic") {
+
+            temporal_lower <- ci_int$basic[4]
+            temporal_upper <- ci_int$basic[5]
+
+          } else if (boot_ci_type == "bca") {
+
+            temporal_lower <- ci_int$bca[4]
+            temporal_upper <- ci_int$bca[5]
+
+          } else {
+
+            stop("boot_ci_type should be 'norm', 'perc', 'stud', 'basic' or 'bca'")
+
+          }
         }
 
 
@@ -1310,6 +1405,10 @@ analysed_period
 
     place_list = 1
 
+    if (k_end < k_running_window){
+      stop("k_running_window is less than the number of analysed years. Reduce the argument k_running_window")
+    }
+
     for (w in 0:(k_end - k_running_window)){
 
       dataset_temp <- dataset[(1+w):(k_running_window + w),]
